@@ -1,28 +1,29 @@
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import, division, print_function
 
-from marshmallow import Schema, fields, post_load, post_dump
+from marshmallow import fields
 
-from polyaxon_schemas.base import BaseConfig
+from polyaxon_schemas.base import BaseConfig, BaseSchema
 
 
-class AccessTokenSchema(Schema):
+class AccessTokenSchema(BaseSchema):
     username = fields.Str()
     token = fields.Str()
 
-    class Meta:
-        ordered = True
-
-    @post_load
-    def make(self, data):
-        return AccessTokenConfig(**data)
-
-    @post_dump
-    def unmake(self, data):
-        return AccessTokenConfig.remove_reduced_attrs(data)
+    @staticmethod
+    def schema_config():
+        return AccessTokenConfig
 
 
 class AccessTokenConfig(BaseConfig):
+    """
+    Access token config.
+
+
+    Args:
+        username: `str`. The user's username.
+        token: `str`. The user's token.
+    """
     SCHEMA = AccessTokenSchema
     IDENTIFIER = 'token'
 
@@ -31,23 +32,24 @@ class AccessTokenConfig(BaseConfig):
         self.token = token
 
 
-class CredentialsSchema(Schema):
+class CredentialsSchema(BaseSchema):
     username = fields.Str()
     password = fields.Str()
 
-    class Meta:
-        ordered = True
-
-    @post_load
-    def make(self, data):
-        return CredentialsConfig(**data)
-
-    @post_dump
-    def unmake(self, data):
-        return CredentialsConfig.remove_reduced_attrs(data)
+    @staticmethod
+    def schema_config():
+        return CredentialsConfig
 
 
 class CredentialsConfig(BaseConfig):
+    """
+    Credentials config.
+
+
+    Args:
+        username: `str`. The user's username.
+        password: `str`. The user's password.
+    """
     SCHEMA = CredentialsSchema
     IDENTIFIER = 'credentials'
 
