@@ -3,12 +3,16 @@ from __future__ import absolute_import, division, print_function
 
 import os
 
-from polyaxon_schemas.exceptions import PolyaxonfileError, PolyaxonConfigurationError
-from polyaxon_schemas.polyaxonfile.specification import GroupSpecification
-from polyaxon_schemas.utils import to_list
+import rhea
+
+from hestia.list_utils import to_list
+
+from polyaxon_schemas.exceptions import PolyaxonConfigurationError, PolyaxonfileError
+from polyaxon_schemas.polyaxonfile.specification import SPECIFICATION_BY_KIND
+from polyaxon_schemas.polyaxonfile.specification.base import BaseSpecification
 
 
-class PolyaxonFile(GroupSpecification):
+class PolyaxonFile(object):
     """Parses Polyaxonfiles, and validate that it respects the current file specification"""
 
     def __init__(self, filepaths):
@@ -17,16 +21,13 @@ class PolyaxonFile(GroupSpecification):
             if not os.path.isfile(filepath):
                 raise PolyaxonfileError("`{}` must be a valid file".format(filepath))
         self._filenames = [os.path.basename(filepath) for filepath in filepaths]
+        data = rhea.read(filepaths)
+        kind = BaseSpecification.get_kind(data=data)
         try:
-            super(PolyaxonFile, self).__init__(filepaths)
+            self.specification = SPECIFICATION_BY_KIND[kind](data)
         except PolyaxonConfigurationError as e:
             raise PolyaxonfileError(e)
 
     @property
     def filenames(self):
         return self._filenames
-
-    @property
-    def filepaths(self):
-        return self.values
-
