@@ -2,11 +2,12 @@
 from __future__ import absolute_import, division, print_function
 
 import uuid
-from datetime import datetime
+
 from unittest import TestCase
 
-from polyaxon_schemas.data import DataDetailsConfig, DataConfig, DatasetConfig
-from polyaxon_schemas.utils import local_now
+from hestia.tz_utils import local_now
+
+from polyaxon_schemas.data import DataConfig, DataDetailsConfig, DatasetConfig
 
 
 class TestDataConfigs(TestCase):
